@@ -74,6 +74,7 @@
 # include <ucontext.h>
 #endif
 #ifdef __FreeBSD__
+# include <machine/fpu.h>
 # include <sys/sysctl.h>
 # include <sys/procctl.h>
 #ifndef PROC_STACKGAP_STATUS
@@ -780,6 +781,17 @@ void os::print_context(outputStream *st, const void *context) {
   st->print(", ERR=" INTPTR_FORMAT, (intptr_t)uc->context_err);
   st->cr();
   st->print("  TRAPNO=" INTPTR_FORMAT, (intptr_t)uc->context_trapno);
+#  ifdef __FreeBSD__
+  // Add XMM registers + MXCSR. Note that C2 uses XMM to spill GPR values including pointers.
+  st->cr();
+  st->cr();
+  struct savefpu *savefpu = (struct savefpu *)uc->uc_mcontext.mc_fpstate;
+  for (int i = 0; i < 16; ++i) {
+    const int64_t* xmm_val_addr = (int64_t*)&(savefpu->sv_xmm[i]);
+    st->print_cr("XMM[%d]=" INTPTR_FORMAT " " INTPTR_FORMAT, i, xmm_val_addr[1], xmm_val_addr[0]);
+  }
+  st->print("  MXCSR=" UINT32_FORMAT_X_0, savefpu->sv_env.en_mxcsr);
+#  endif
 #else
   st->print(  "EAX=" INTPTR_FORMAT, (intptr_t)uc->context_eax);
   st->print(", EBX=" INTPTR_FORMAT, (intptr_t)uc->context_ebx);
@@ -798,23 +810,6 @@ void os::print_context(outputStream *st, const void *context) {
   st->cr();
 }
 
-void os::print_tos_pc(outputStream *st, const void *context) {
-  if (context == nullptr) return;
-
-  const ucontext_t* uc = (const ucontext_t*)context;
-
-  address sp = (address)os::Bsd::ucontext_get_sp(uc);
-  print_tos(st, sp);
-  st->cr();
-
-  // Note: it may be unsafe to inspect memory near pc. For example, pc may
-  // point to garbage if entry point in an nmethod is corrupted. Leave
-  // this at the end, and hope for the best.
-  address pc = os::fetch_frame_from_context(uc).pc();
-  print_instructions(st, pc, sizeof(char));
-  st->cr();
-}
-
 void os::print_register_info(outputStream *st, const void *context, int& continuation) {
   const int register_count = AMD64_ONLY(16) NOT_AMD64(8);
   int n = continuation;
